#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-4Q318iNA7bh2z7DE4qCtN4
key:                  lsp-2.2.0.0-4Q318iNA7bh2z7DE4qCtN4
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  30baf1298557c2b53c775835fd17b14a
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-IgyP12tUS20Ahm1XfwPLKI:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-IgyP12tUS20Ahm1XfwPLKI:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-IgyP12tUS20Ahm1XfwPLKI:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-IgyP12tUS20Ahm1XfwPLKI:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-4Q318iNA7bh2z7DE4qCtN4
depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie
    async-2.2.6-EpK7QlrOASTBz80Gb3A8ju
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-FxiHVtJAzEMCS7Nj1ybbql
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-CNoNcGLK9KJ5X5nXfJeai3
    lens-5.3.4-kk6OqUq8ZY4lLpzN7435U
    lens-aeson-1.2.3-K1JngaG9OfHHT9om9Ah6qo
    lsp-types-2.0.2.0-IgyP12tUS20Ahm1XfwPLKI mtl-2.3.1
    prettyprinter-1.7.1-DrhJgh2zvVyDSlphpqlv9X
    random-1.2.1.3-1Uit38DFsvW5UeAKObGtgy
    row-types-1.0.1.2-LskKoSJ0PMyI4P3Kr430zm
    sorted-list-0.2.3.1-8otktGKUfzo87v0AC4Zlkd stm-2.5.1.0
    temporary-1.3-C4AWJcx6OU755V1dgCzpdm text-2.0.2
    text-rope-0.3-5I7Pwcc6qSWHjN3BaUVYgq transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    uuid-1.3.16.1-A1XTGtbTbec3kAFoJMDYR8

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

